# pipmore

Find the latest package version supported by a specific python version

## Usage

To find the latest version of **flask** that can be installed with **Python 3.6**:

```console
$ pipmore flask 3.6
2.0.3
```
